.BG
.FN dcuhre
.TL
Numerical Integration
.DN
Numerical integration of a vector valued multivariate function
over a given hyperrectangular region.
.CS
dcuhre( f, low, hi, ..., name="x", epsabs=0.0, epsrel=1.0e-4,
        mincall=0, maxcall=10000, key=0)
.RA
.AG f
The S function to be integrated.  `f' is  a function of a vector, `x',
and possibly other arguments.  `f' returns either a scalar value or
a numeric vector.  The scalar case is most frequently encountered.
.PP
Let NDIM = length(x) and NUMFUN = length(f(x)) then it is required that
      1 < NDIM <= 15
      NUMFUN >= 1
.AG low
Lower limit of integration of length NDIM.
.AG hi
Upper limit of integration of length NDIM.
.OA
.AG ...
Other arguments to `f' (other than `x').  These must be specified by name,
not by position.  For example, use `a=10', instead of 10 for the
argument `a' of `f'.
.AG name
A character string containing the name of the variable of integration. Default is `"x"'.
.AG epsabs
Bound on absolute error of integral. Default is 0.0
.AG epsrel
Bound on relative error of integral. Default is 1.0e-4. One of `epsabs' and `epsrel' must be greater than 0.
.AG mincall
Minimum number of function calls required. Default is 0.
.AG maxcall
Maximum number of function calls `dcuhre' is allowed to make. Default is 10000.
.AG key
Select the integration rule. The table below is of the polynomial degrees of the different integration rules depending on the value of key and NDIM.
.PP
.CW
KEY   NDIM = 2   NDIM = 3   NDIM > 3
 0      13         11         9
 1      13         --        --
 2      --         11        --
 3       9          9         9
 4       7          7         7
.RT
a list containing the following components:
.AG result
A vector of length NUMFUN containing approximations to all components of the vector integral.
.AG abserr
A vector of length NUMFUN containing estimates of absalute errors for all components of the vector integral
.AG neval
The number of times the function, `f', was evaluated.
.SH NOTES
`dcuhre' can not be called recursively.
.PP
Unless you are familiar with the arcana of S argument matching, use the
full names of all arguments in `...' and in the optional arguments following `...'. 
.DT
Uses Fortran code in algorithm 698 of toms. See reference for further details.
.SH REFERENCES
Berntsen, Jarle and Espelid, Terje O. and Genz, Alan (1991).
Algorithm 698: DCUHRE: An Adaptive Multidimensional Integration Routine for a Vector of Integrals.
.ul
ACM Transactions of Mathematical Software.
\fB17\fR, 452-456.
.EX
# Integrate a function of x over x
f <- function(x){return(x[1]*x[2])}
low <- c(0,0)
hi <- c(1,1)
dcuhre(f,low,hi)
# Integrate a function of p,q and r over q
f <- function(p,q,r){return(sum(p)*sum(q)*r[1]*r[2]*r[3])}
dcuhre(f,low=c(0,0,0),hi=c(1,1,1),name="r",p=c(1,2),q=c(4,5,6))
.KW numeric integration
.WR
