.BG
.FN gkint
.TL
Numeric Integration
.DN
Numerical integration of a function over a given region using a 7-15 point Gauss-Kronrod pair.
.CS
gkint(f, low, hi, ..., name="x", epsabs=1e-10, epsrel=1e-06)
.RA
.AG f
S function to be integrated.  `f' is a function of `x' and possibly of other
arguments.
.AG low
Lower limit of integration.
.AG hi
Upper limit of integration.
.OA
.AG ...
Other arguments to `f' (other than `x').  These must be specified by name,
not by position.  For example, use `a=10', instead of 10 for the
argument `a' of `f'.
.AG name
A character string containing the name of the variable of integration. Default is `"x"'.
.AG epsabs
Absolute accuracy of the integration requested. Default is 1e-10.
.AG epsrel
Relative accuracy of the integration requested. Should be between 0 and 1. Default is 1e-4.
.RT
list incuding the following components:
.AG result
The approximation to the integral.
.AG abserr
Upper bound on absolute error of the integral.
.AG neval
The number of time the function, `f', was evaluated.
.SH NOTES
gkint can not be called recursively.
.PP
Unless you are familiar with the arcana of S argument matching, use the
full names of all arguments in `...' and in the optional arguments following `...'. 
.DT
Uses routine DQAG from QUADPACK.
.PP
The original DQAG gives the user a choice of local integration rules.
For this adaptation, a 7-15 point Gauss-Kronrod pair is used.
.SH REFERENCES
Piessens, R., DeDoncker-Kapenga, E., Uberhuber, C., and Hahaner, D. (1983).
.ul
QUADPACK: A Subroutine Package for Automatic Integration
Springer-Verlag, Berlin. (1983)
.EX
# Integrate a function of x
sq <- function(x){x^2}
gkint(sq,0,1)
# Integrate a function of p and q over q
sq <- function(p,q){return(p*q^2)}
gkint(sq,0,1,name="q",p=5)
.KW numeric integration
.WR
