#include "S.h"
void F77_NAME(dcuhre)();
void F77_NAME(dcusfn)( char **, long*, double*, long*, double* );
void F77_NAME(dqag)();
void F77_NAME(evlsfn)( char**, double*, double* );


void dcucall(ndim,numfun,a,b,minpts,maxpts,funsub,epsabs,epsrel,key,nw,
	     restar,result,abserr,neval,ifail,work)
long *ndim;      /* Number of variables in integrand(s) */
long *numfun;    /* Number of components in the vector integrand function */
double *a;       /* Lower limit of integration */
double *b;       /* Uppder limit of integration */
long *minpts;    /* Minimum number of funsub calls */
long *maxpts;    /* Maximum number of funsub calls *
void **funsub;   /* function to be integrated */
double *epsabs;  /* Requested absalute error */
double *epsrel;  /* Requested relative error */
long *key;       /* Selects integration rule */
long *nw;        /* Length of work array */
long *restar;    /* restar = 0, this is the first attempt
                           = 1, continuation of a previous attempt */
double *result;  /* An array of the approximation to the integrals */
double *abserr;  /* An array of estimates for absolute errors */
long *neval;     /* Number of function evaluations used */
long *ifail;     /* Exit condition indicator */
double *work;    /* Work array */

{
  F77_CALL(dcuhre)(ndim,numfun,a,b,minpts,maxpts,funsub,
	  epsabs,epsrel,key,nw,restar,result,abserr,
	  neval,ifail,work);
}

/***********************************************************************
  file dcusfn.c
  ++++++++++++++++++++

              Evaluation of an S Function
                  for use by dcuhre integrating routine
  ______________________________________________________________________

  This is c code to evaluate an S function f at x and return
  the value in ans as type double.
 
  f takes one argument which must be a vector of type double.
  f returns a vector of type double.

  We use the strategy described on page 210 of New S to assure that
  a single vector of numbers is returned by the user function.

                      Arguments

  f --> S function of one argument of a vector of type double.  f is 
        passed here through a trivial C driver that invokes a
        Fortran routine in which all statements 
	CALL FUNSUB(NDIM,X,NUMFUN,FUNVLS) are changed
        to CALL DCUSFN( FUNSUB, NDIM, X, FUNVLS ).

  ndim --> length of x
                   ndim is long

  x --> value at which f is to be evaluated.
                   x is double

  numfun --> length of f(x)
                   numfun is long
                   
  funvls <-- value of f(x).
                   funvls is double

***********************************************************************/
#include <stdio.h>
void F77_SUB(dcusfn)( f, ndim, x, numfun, funvls )
char **f;
long *ndim;
double *x;
long *numfun;
double *funvls;
{  
  char *func;
  char *args[1]; 
  char *result[1];
  char *mode[1]; 
  long length[1];
  int i;
  double *fnew;
  
  /* Assign values for parameters of call_S */

  func = f[0];
  mode[0] = "double";
  length[0] = *ndim;
  args[0] = (char *) x;

  /* Use call_S to evaluate S function */

  call_S( func, 1L, args, mode, length, 0, 1L, result); 

  /* Assign answers in result to funvls variable */
  fnew = (double *) result[0];
  for (i = 0; i < *numfun; i++) {
    *funvls++ = *fnew++;
  }
}


void drdqag( f, a, b, epsabs, epsrel, result, abserr, neval,
             ier, limit, lenw, last, iwork, work )
void **f;
double *a, *b, *epsabs, *epsrel, *result, *abserr;
int *neval, *ier, *limit, *lenw, *last;
int iwork[100];
double *work[400];
{ 
  F77_CALL(dqag)( f, a, b, epsabs, epsrel, result, abserr, neval,
	ier, limit, lenw, last, iwork, work ); 
}


/***********************************************************************
  file evlsfn.c
  ++++++++++++++++++++

              Evaluation of an S Function
                  of One  Argument
  ______________________________________________________________________

  This is c code to evaluate an S function f at x and return
  the value in ans as type double.
 
  Note that the (void) function name is evlsfn_ so that it can be
  invoked from Fortran.

  f takes one argument which must be type double.
  f returns an answer of type double.

  We use the strategy described on page 210 of New S to assure that
  a single vector of numbers is returned by the user function.


                      Arguments

  f --> S function of one argument of type double.  f is 
        passed here through a trivial C driver that invokes a
        Fortran routine in which all statements FX = F(X) are changed
        to CALL EVLSFN( F, X, FX ).

  x --> value at which f is to be evaluated.
                   x is double

  ans <-- value of f(x).
                   ans is double

***********************************************************************/
#include <stdio.h>
void F77_SUB(evlsfn)( f, x, ans )
char **f; double *x; double *ans;
{  char *func;
   char *args[1]; char *result[1];
   char *mode[1]; long length[1];
   mode[0] = "double"; length[0] = 1;
   args[0] = (char *) x;
   func = f[0];
   call_S( func, 1L, args, mode, length, 0, 1L, result); 
   *ans = *( (double *) result[0] );
 }
